@@ -257,10 +257,10 @@ iSCSIId = intRange('iSCSIId', 0, 0x0fff)
 iSCSIName = r'^[a-z0-9\-.:]+$'
 iSCSIPGName = r'^[A-Za-z0-9_\-.:]+$'
 
-OnAttached = oneOf("fail", "detach", "detachForce", "export")
-DematerializationStatus = oneOf("pending", "allObjectsUsed", "complete")
-DeleteBlocked = oneOf("not blocked", "pending", "rebasing", "flushing", "volume not found", "generation mismatch", "disk down", "multiple children", "peer down", "write not completed", "recovering from remote", "parent recovering from remote", "unknown")
-MultiClusterState = oneOf("owner", "ownerExported", "slaveCopy", "clusterLocal", "clusterLocalExported", "clusterLocalAutoReconcile", "clusterLocalAutoReconcileExported")
+OnAttached = oneOf("OnAttached", "fail", "detach", "detachForce", "export")
+DematerializationStatus = oneOf("DematerializationStatus", "pending", "allObjectsUsed", "complete", "blockedRelocate", "blockedParentRelocate", "blockedParentRemoving", "blockedParentDifferentVag")
+DeleteBlocked = oneOf("DeleteBlocked", "not blocked", "pending", "rebasing", "flushing", "volume not found", "generation mismatch", "disk down", "multiple children", "peer down", "write not completed", "recovering from remote", "parent recovering from remote", "unknown")
+MultiClusterState = oneOf("MultiClusterState", "owner", "ownerExported", "slaveCopy", "clusterLocal", "clusterLocalExported", "clusterLocalAutoReconcile", "clusterLocalAutoReconcileExported")
 
 
 # NETWORK
@@ -290,7 +290,7 @@ class PeerDesc(object):
 
 
 # SERVER
-@JsonObject(nodeId=NodeId, version=str, startTime=eitherOr(int, None))
+@JsonObject(nodeId=maybe(NodeId), version=str, startTime=eitherOr(int, None))
 class Service(object):
     '''
     nodeId: The ID of the node on which the service is running.
@@ -1664,7 +1664,7 @@ class AllPeersActiveRequestsPeerDesc():
     '''
 
 
-@JsonObject(status=oneOf('Status', 'too_old', 'peer_down', 'peerDone', 'timeout', 'streamNotConnected', 'streamOverfilled', 'invalidResponse'))
+@JsonObject(status=oneOf('Status', 'peer_down', 'peerDone', 'timeout', 'streamNotConnected', 'streamOverfilled', 'invalidResponse'))
 class AllPeersActiveRequestsSimpleStats(AllPeersActiveRequestsPeerDesc):
     '''
     status: status of the request to the service
